summaryrefslogtreecommitdiffstats
path: root/konq-plugins/webarchiver/webarchivecreator.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:22:56 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:22:56 +0000
commit7346aee26bf190a7e70333c40fab4caca847cd27 (patch)
tree4b019b434f88dcc3eeaafe1d3f26240b4c4718e8 /konq-plugins/webarchiver/webarchivecreator.cpp
parent23a3d3aa5b44cbdf305495919866d9dbf4f6da54 (diff)
downloadtdeaddons-7346aee26bf190a7e70333c40fab4caca847cd27.tar.gz
tdeaddons-7346aee26bf190a7e70333c40fab4caca847cd27.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeaddons@1157634 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'konq-plugins/webarchiver/webarchivecreator.cpp')
-rw-r--r--konq-plugins/webarchiver/webarchivecreator.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/konq-plugins/webarchiver/webarchivecreator.cpp b/konq-plugins/webarchiver/webarchivecreator.cpp
index cba7f18..1ffd242 100644
--- a/konq-plugins/webarchiver/webarchivecreator.cpp
+++ b/konq-plugins/webarchiver/webarchivecreator.cpp
@@ -21,9 +21,9 @@
#include <time.h>
-#include <qpixmap.h>
-#include <qimage.h>
-#include <qpainter.h>
+#include <tqpixmap.h>
+#include <tqimage.h>
+#include <tqpainter.h>
#include <kapplication.h>
#include <khtml_part.h>
@@ -48,12 +48,12 @@ WebArchiveCreator::~WebArchiveCreator()
delete m_html;
}
-bool WebArchiveCreator::create(const QString &path, int width, int height, QImage &img)
+bool WebArchiveCreator::create(const TQString &path, int width, int height, TQImage &img)
{
if (!m_html)
{
m_html = new KHTMLPart;
- connect(m_html, SIGNAL(completed()), SLOT(slotCompleted()));
+ connect(m_html, TQT_SIGNAL(completed()), TQT_SLOT(slotCompleted()));
m_html->setJScriptEnabled(false);
m_html->setJavaEnabled(false);
m_html->setPluginsEnabled(false);
@@ -70,8 +70,8 @@ bool WebArchiveCreator::create(const QString &path, int width, int height, QImag
killTimers();
// render the HTML page on a bigger pixmap and use smoothScale,
- // looks better than directly scaling with the QPainter (malte)
- QPixmap pix;
+ // looks better than directly scaling with the TQPainter (malte)
+ TQPixmap pix;
if (width > 400 || height > 600)
{
if (height * 3 > width * 4)
@@ -82,14 +82,14 @@ bool WebArchiveCreator::create(const QString &path, int width, int height, QImag
else
pix.resize(400, 600);
// light-grey background, in case loadind the page failed
- pix.fill( QColor( 245, 245, 245 ) );
+ pix.fill( TQColor( 245, 245, 245 ) );
int borderX = pix.width() / width,
borderY = pix.height() / height;
- QRect rc(borderX, borderY, pix.width() - borderX * 2, pix.height() - borderY *
+ TQRect rc(borderX, borderY, pix.width() - borderX * 2, pix.height() - borderY *
2);
- QPainter p;
+ TQPainter p;
p.begin(&pix);
m_html->paint(&p, rc);
p.end();
@@ -98,7 +98,7 @@ bool WebArchiveCreator::create(const QString &path, int width, int height, QImag
return true;
}
-void WebArchiveCreator::timerEvent(QTimerEvent *)
+void WebArchiveCreator::timerEvent(TQTimerEvent *)
{
m_html->closeURL();
m_completed = true;